@@ -18,22 +18,19 @@
 */
 
 #include "importimapsettingsakonadicheckjob.h"
+#include "importimapsettingsakonadipassword.h"
 #include "libsieveeditor_export.h"
 #include "sieveeditor_debug.h"
-#include "sieveserversettings.h"
 #include <KLocalizedString>
 #include <KConfigGroup>
 #include <KSharedConfig>
 #include <QStandardPaths>
 #include <QDir>
 #include <QFile>
-#include <KWallet>
 
-LIBSIEVEEDITOR_EXPORT bool sieveeditor_import_wallet = true;
 ImportImapSettingsAkonadiCheckJob::ImportImapSettingsAkonadiCheckJob(QObject *parent)
     : AbstractImapSettingsCheckJob(parent)
 {
-
 }
 
 ImportImapSettingsAkonadiCheckJob::~ImportImapSettingsAkonadiCheckJob()
@@ -116,26 +113,8 @@ bool ImportImapSettingsAkonadiCheckJob::importSettings(const QString &directory,
             config.sieveSettings.serverName = imapServerName; //FIXME
             //TODO
         }
-        if (sieveeditor_import_wallet) {
-            KWallet::Wallet *wallet = SieveServerSettings::self()->wallet();
-            QString password;
-            if (wallet) {
-                bool passwordStoredInWallet = false;
-                if (wallet && wallet->hasFolder(QStringLiteral("imap"))) {
-                    wallet->setFolder(QStringLiteral("imap"));
-                    wallet->readPassword(resourceConfig->name(), password);
-                    passwordStoredInWallet = true;
-                }
-                if (passwordStoredInWallet) {
-                    config.sieveImapAccountSettings.setPassword(password);
-                    if (reuseImapSettings) {
-                        config.sieveSettings.password = password;
-                    } else {
-                        //TODO
-                    }
-                }
-            }
-        }
+        Q_ASSERT_X(mPasswordImporter, "Missing mPasswordImporter", "You must create a mPasswordImporter");
+        mPasswordImporter->importPasswords(config, resourceConfig, reuseImapSettings);
         if (config.isValid()) {
             Q_EMIT importSetting(filename, config);
             return true;
