@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -28,7 +28,7 @@ class SieveEditorCentralWidget : public QStackedWidget
 {
     Q_OBJECT
 public:
-    explicit SieveEditorCentralWidget(QWidget *parent = Q_NULLPTR, KActionCollection *ac = Q_NULLPTR);
+    explicit SieveEditorCentralWidget(QWidget *parent = nullptr, KActionCollection *ac = nullptr);
     ~SieveEditorCentralWidget();
 
     SieveEditorMainWidget *sieveEditorMainWidget() const;
