@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -29,7 +29,7 @@ class SieveEditorScriptWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit SieveEditorScriptWidget(QWidget *parent = Q_NULLPTR);
+    explicit SieveEditorScriptWidget(QWidget *parent = nullptr);
     ~SieveEditorScriptWidget();
 
     void setScript(const QString &script);
